@@ -17,6 +17,7 @@
 #include <qcolor.h>
 #include "latexeditor.h"
 #include "linenumberwidget.h"
+#include "findwidget.h"
 
 class LatexEditorView : public QWidget  {
    Q_OBJECT
@@ -24,6 +25,7 @@ public:
 	LatexEditorView(QWidget *parent, QFont & efont,bool line, QColor colMath, QColor colCommand, QColor colKeyword);
 	~LatexEditorView();
   LatexEditor *editor;
+  FindWidget *findwidget;
   void changeSettings(QFont & new_font,bool line);
 private:
   LineNumberWidget* m_lineNumberWidget;
